Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigureCommand ¶
ConfigureCommand applies platform process settings for shell commands.
Types ¶
type CommandCleanup ¶ added in v0.1.21
type CommandCleanup struct {
// contains filtered or unexported fields
}
func AttachCommandCleanup ¶ added in v0.1.21
func AttachCommandCleanup(cmd *exec.Cmd) *CommandCleanup
func (*CommandCleanup) Cleanup ¶ added in v0.1.21
func (c *CommandCleanup) Cleanup() error
type LookPathFunc ¶
LookPathFunc matches exec.LookPath and allows tests to control discovery.
type Resolver ¶
type Resolver struct {
GOOS string
LookPath LookPathFunc
Env []string
}
Resolver resolves shell commands for a target platform.
func (Resolver) DescribeRuntime ¶
func (r Resolver) DescribeRuntime() RuntimeDescription
DescribeRuntime describes the resolver's shell runtime.
type RuntimeDescription ¶
RuntimeDescription describes the shell language the current runtime expects.
func DescribeRuntime ¶
func DescribeRuntime() RuntimeDescription
DescribeRuntime describes the current host shell runtime.
func (RuntimeDescription) CommandGuidance ¶
func (d RuntimeDescription) CommandGuidance() string
CommandGuidance returns model-facing command-language guidance for shell_run.
func (RuntimeDescription) ShellSummary ¶
func (d RuntimeDescription) ShellSummary() string
ShellSummary returns a compact user-facing shell execution summary.
func (RuntimeDescription) ToolGuidance ¶
func (d RuntimeDescription) ToolGuidance() string
ToolGuidance returns a compact sentence suitable for a tool description.
Click to show internal directories.
Click to hide internal directories.